;(function (document, $, page) {

    function openDialog() {
        $('#smartling-job-dialog').get(0).show();
    }

    function closeDialog() {
        $('#smartling-job-dialog').get(0).hide();
    }

    function initializeControls() {
        $('#pageinfo-popover').bind('DOMSubtreeModified', function () {
            var $translateAsJobMenuItem = $('#smartling-job-trigger');

            // Hack to support both AEM 6.2 and 6.3:
            //    6.2: uses minimal buttons
            //    6.3: uses regular buttons
            // So we check which button style is used by the previous menu item
            if ($translateAsJobMenuItem.prev().hasClass('coral-MinimalButton')) {
                $translateAsJobMenuItem.removeClass('coral-Button');
                $translateAsJobMenuItem.addClass('coral-MinimalButton');
            }

            $translateAsJobMenuItem.click(openDialog);
        });

        var foundationUi = $(window).adaptTo('foundation-ui');
        var $dialog = $('#smartling-job-dialog');
        var $tabs = $('#smartling-job-dialog-tabs');

        $dialog.find('coral-datepicker').each(function () {
            this.min = moment().startOf('day').add(1, 'days').toDate();
        });

        $dialog.find('form')
            .on('foundation-form-submitted', function (e, success) {
                if (success) {
                    closeDialog();
                    foundationUi.notify('Success', 'Page was added to a job', 'success');
                }
            })
            .on('reset', function () {
                this.querySelector('coral-checkbox[name="authorizeJob"]').checked = true;
                this.querySelector('coral-checkbox[name="isDeep"]').checked = false;
                this.querySelector('coral-checkbox[name="forceResubmission"]').checked = true;
            });

        $('#smartling-job-select').on('coral-select:showitems', function (e) {
            var select = this;

            if (select.items.length === 0) {
                e.preventDefault();

                $.ajax({
                    url: '/services/smartling/jobs?path=' + page.path
                }).done(function (data) {
                    data.forEach(function (job) {
                        var redableState;
                        if (job.state == 'AWAITING_AUTHORIZATION') {
                            redableState = '(Unauthorized)';
                        } else if (job.state == 'IN_PROGRESS') {
                            redableState = '(In progress)';
                        } else if (job.state == 'COMPLETED') {
                            redableState = '(Completed)'
                        }
                        else {
                            redableState = '(' + job.state + ')'
                        }
                        select.items.add({value: job.uid, content: {innerHTML: job.name + ' ' + redableState}});
                    });
                }).always(function () {
                    select.loading = false;
                });
            }
        }).on('change', function (e) {
            var form = $(this).closest('form').get(0);
            var dueDateFiled = form.querySelector('coral-datepicker[name="jobDueDate"]');
            var targetLocalesField = form.querySelector('coral-select[name="targetLocaleCodes"]');

            foundationUi.wait(form);
            $.ajax({
                url: '/services/smartling/jobs/detail?path=' + page.path + '&uid=' + e.target.value
            }).done(function (data) {
                dueDateFiled.value = data.dueDate;
                targetLocalesField.values = data.targetLocaleIds;
                $(targetLocalesField).parent().find(".coral-Form-fielderror").hide();
                $(".coral-Tab").removeAttr("invalid");
                targetLocalesField.invalid = false;
            }).fail(function () {
                dueDateFiled.value = null;
                targetLocalesField.values = [];
            }).always(function () {
                foundationUi.clearWait();
            });
        });

        $tabs.on('coral-panelstack:change', function () {
            var $submitButton = $('#smartling-job-dialog-submit');
            var $form = $(this.panelStack.selectedItem).find('form');

            var $unselectedTab = $('#smartling-job-dialog').find('coral-tab[aria-selected="false"]').get(0);
            if ($submitButton.length) {
                $submitButton.get(0).label.innerText = $unselectedTab.label.innerText;
            }
            $submitButton.attr('form', $form.attr('id'));

            $(".coral-Form-fielderror").hide();
            $(".coral-Form-field").removeAttr("invalid");
            $(".coral-Tab").removeAttr("invalid");
        });

        $dialog.on('coral-overlay:close', '*', function (e) {
            e.stopPropagation();
        }).on('coral-overlay:close', function () {
            $(this).find('form').each(function () {
                this.reset();
            });

            $(".coral-Form-fielderror").hide();
            $(".coral-Form-field").removeAttr("invalid");
            $(".coral-Tab").removeAttr("invalid");
            $tabs.get(0).tabList.items.first().selected = true;
        });

        $("#create-job-form").find('[name="jobName"]').on("input", function () {
            if ($("#create-job-form").find('[name="jobName"]').attr("aria-invalid") === "true") {
                $("#create-job-form").find('[name="jobName"]').parent().find(".coral-Form-fielderror").hide();
            }
        });

        $dialog.on("foundation-validation-invalid", function (event) {
            var target = $(event.target);
            target.parent().find(".coral-Form-fielderror").show();
        });
    }

    $(document).ready(initializeControls);

})(jQuery(document), Granite.$, Granite.author.page);